@@ -18,7 +18,7 @@ byComplexity <- function(x, model)
              # complexity faster than number of splits
              x[order(x$n.trees, x$interaction.depth, x$shrinkage),] 
            },
-           rf =, rfNWS =, rfLSF =, gpls =, pls =, PLS =, pam =, cforest =,
+           rf =, rfNWS =, rfLSF =, gpls =, pcr =, pls =, PLS =, pam =, cforest =,
            nb =, rpart =, ctree2 =, logitBoost=, J48 =, LMT =, ppr =, mda =, pda =, pda2 =,
            lars =, lars2 =
            {
@@ -123,7 +123,8 @@ byComplexity <- function(x, model)
            },           
            PART = x[order(x$pruned, -x$threshold),],
            sda = x[order(x$diagonal),],
-           glmnet = x[order(-x$lambda, x$alpha),]
+           glmnet = x[order(-x$lambda, x$alpha),],
+           stop("no sorting routine for this model")
            )
 
   }
